@@ -142,13 +142,14 @@ def filename(stream):
 
 
 def output(options, extention="mp4", openfd=True, mode="wb", **kwargs):
+    subtitlefiles = ["srt", "smi", "tt","sami", "wrst"]
     if is_py2:
         file_d = file
     else:
         file_d = io.IOBase
 
     if options.output != "-":
-        ext = re.search(r"(\.\w{2,3})$", options.output)
+        ext = re.search(r"(\.\w{2,4})$", options.output)
         if not ext:
             options.output = "%s.%s" % (options.output, extention)
         if options.output_auto and ext:
@@ -158,7 +159,7 @@ def output(options, extention="mp4", openfd=True, mode="wb", **kwargs):
         log.info("Outfile: %s", options.output)
         if os.path.isfile(options.output) or \
                 findexpisode(os.path.dirname(os.path.realpath(options.output)), options.service, os.path.basename(options.output)):
-            if extention == "srt":
+            if extention in subtitlefiles:
                 if not options.force_subtitle:
                     log.error("File (%s) already exists. Use --force-subtitle to overwrite" % options.output)
                     return None
@@ -179,20 +180,23 @@ def output(options, extention="mp4", openfd=True, mode="wb", **kwargs):
 
 
 def findexpisode(directory, service, name):
+    subtitlefiles = ["srt", "smi", "tt","sami", "wrst"]
     match = re.search(r"-(\w+)-\w+.(\w{2,3})$", name)
     if not match:
         return False
+    
     videoid = match.group(1)
     extention = match.group(2)
+
     files = [f for f in os.listdir(directory) if os.path.isfile(os.path.join(directory, f))]
     for i in files:
         match = re.search(r"-(\w+)-\w+.(\w{2,3})$", i)
         if match:
             if service:
-                if extention == "srt":
+                if extention in subtitlefiles:
                     if name.find(service) and match.group(1) == videoid and match.group(2) == extention:
                         return True
-                elif match.group(2) != "srt" and match.group(2) != "m4a":
+                elif match.group(2) not in subtitlefiles and match.group(2) != "m4a":
                     if name.find(service) and match.group(1) == videoid:
                         return True
 
