@@ -17,7 +17,7 @@ class Solidtango(Service):
     def get(self):
         data = self.get_urldata()
 
-        if self.exclude(self.options):
+        if self.exclude():
             yield ServiceError("Excluding video")
             return
         match = re.search('src="(http://mm-resource-service.herokuapp.com[^"]*)"', data)
